@@ -41,7 +41,6 @@ import com.sun.electric.database.topology.PortInst;
 import com.sun.electric.technology.ArcProto;
 import com.sun.electric.technology.PrimitiveNode;
 import com.sun.electric.technology.PrimitivePort;
-import com.sun.electric.technology.SizeOffset;
 import com.sun.electric.technology.TransistorSize;
 
 import java.awt.geom.Rectangle2D;
@@ -79,9 +78,7 @@ public class L extends Output
 	/**
 	 * Creates a new instance of the L netlister.
 	 */
-	L()
-	{
-	}
+	L() {}
 
 	/**
 	 * Method to write all cells below a given Cell.
@@ -220,9 +217,10 @@ public class L extends Output
 				}
 
 				// special type names for transistors
-				if (fun == PrimitiveNode.Function.TRANMOS) type = "TN";
-				if (fun == PrimitiveNode.Function.TRADMOS) type = "TD";
-				if (fun == PrimitiveNode.Function.TRAPMOS) type = "TP";
+				if (fun.isNTypeTransistor()) type = "TN"; else
+					if (fun.isPTypeTransistor()) type = "TP"; else
+						if (fun == PrimitiveNode.Function.TRADMOS ||
+							fun == PrimitiveNode.Function.TRAPMOSD) type = "TD";
 
 				// write the type and name
 				printWriter.print("\t" + type + " " + getLegalName(ni.getName()));
@@ -248,10 +246,7 @@ public class L extends Output
 			{
 				double wid = ni.getLambdaBaseXSize();
 				double len = ni.getLambdaBaseYSize();
-//				SizeOffset so = ni.getSizeOffset();
-//				double wid = ni.getXSize() - so.getLowXOffset() - so.getHighXOffset();
-//				double len = ni.getYSize() - so.getLowYOffset() - so.getHighYOffset();
-				if (fun == PrimitiveNode.Function.TRANMOS || fun == PrimitiveNode.Function.TRADMOS || fun == PrimitiveNode.Function.TRAPMOS)
+				if (fun.isFET())
 				{
 					TransistorSize ts = ni.getTransistorSize(null);
 					len = ts.getDoubleLength();
@@ -483,7 +478,7 @@ public class L extends Output
 	{
 		if (ni.isCellInstance()) return INSTANCE;
 		PrimitiveNode.Function fun = ni.getFunction();
-		if (fun == PrimitiveNode.Function.TRANMOS || fun == PrimitiveNode.Function.TRADMOS || fun == PrimitiveNode.Function.TRAPMOS) return TRANSISTOR;
+		if (fun.isFET()) return TRANSISTOR;
 		if (fun != PrimitiveNode.Function.PIN) return OTHERNODE;
 		if (ni.getNumConnections() != 2) return OTHERNODE;
 		return TRUEPIN;
